@@ -3,8 +3,8 @@ package Pcore::App::API;
 use Pcore -role, -const, -export;
 use Pcore::Lib::Scalar qw[looks_like_number looks_like_uuid];
 use Pcore::Lib::Scalar qw[is_plain_arrayref];
-use Pcore::Lib::Data qw[from_b64_url];
-use Pcore::Lib::Digest qw[sha3_512];
+use Pcore::Lib::Data qw[from_b64u];
+use Pcore::Lib::Digest qw[sha3_512_bin];
 use Pcore::Lib::Text qw[encode_utf8];
 use Pcore::Lib::UUID qw[uuid_from_bin];
 use Pcore::App::API::Auth;
@@ -161,7 +161,7 @@ sub authenticate ( $self, $token ) {
         $token->[0] = lc $token->[0];
 
         # generate private token hash
-        $private_token_hash = eval { sha3_512 encode_utf8( $token->[1] ) . encode_utf8 $token->[0] };
+        $private_token_hash = eval { sha3_512_bin encode_utf8( $token->[1] ) . encode_utf8 $token->[0] };
 
         $private_token = [ $token->[0], $private_token_hash, $TOKEN_TYPE_PASSWORD ] if !$@;
     }
@@ -182,14 +182,14 @@ sub _unpack_token ( $self, $token ) {
 
     # decode token
     eval {
-        my $token_bin = from_b64_url $token;
+        my $token_bin = from_b64u $token;
 
         # unpack token id
         $token_id = uuid_from_bin( substr $token_bin, 0, 16 )->str;
 
         $token_type = unpack 'C', substr $token_bin, 16, 1;
 
-        $private_token_hash = sha3_512 substr $token_bin, 17;
+        $private_token_hash = sha3_512_bin substr $token_bin, 17;
     };
 
     # error decoding token
