@@ -1,9 +1,9 @@
 package Pcore::App::API::Auth;
 
 use Pcore -class, -res;
-use Pcore::App::API qw[:CONST];
-use Pcore::App::API::Auth::Request;
-use Pcore::Util::Scalar qw[is_callback is_plain_coderef];
+use Pcore::App::API qw[:TOKEN_TYPE :PRIVATE_TOKEN :PERMISSIONS];
+use Pcore::App::API::Request;
+use Pcore::Lib::Scalar qw[is_callback is_plain_coderef is_plain_arrayref];
 
 use overload    #
   q[bool] => sub {
@@ -11,17 +11,15 @@ use overload    #
   },
   fallback => undef;
 
-has app              => ( required => 1 );    # ConsumerOf ['Pcore::App']
+has api              => ( required => 1 );    # ConsumerOf ['Pcore::App::API']
 has is_authenticated => ( required => 1 );    # Bool
-has private_token => ();                      # Maybe [ArrayRef], [ $token_type, $token_id, $token_hash ]
-has is_root       => ();                      # Bool
+has private_token => ();                      # Maybe [ArrayRef]
 has user_id       => ();                      # Maybe [Str]
 has user_name     => ();                      # Maybe [Str]
 has permissions   => ();                      # Maybe [HashRef]
-has depends_on    => ();                      # Maybe [ArrayRef]
 
 *TO_JSON = *TO_CBOR = sub ($self) {
-    return { $self->%{qw[is_authenticated is_root user_id user_name permissions]} };
+    return { $self->%{qw[is_authenticated user_id user_name permissions]} };
 };
 
 sub TO_DUMP ( $self, $dumper, @ ) {
@@ -45,7 +43,7 @@ sub TO_DUMP ( $self, $dumper, @ ) {
 
 sub api_can_call ( $self, $method_id ) {
     if ( $self->{is_authenticated} ) {
-        my $auth = $self->{app}->{api}->authenticate_private( $self->{private_token} );
+        my $auth = $self->{api}->authenticate_private( $self->{private_token} );
 
         return $auth->_check_permissions($method_id);
     }
@@ -57,42 +55,34 @@ sub api_can_call ( $self, $method_id ) {
 sub _check_permissions ( $self, $method_id ) {
 
     # find method
-    my $method_cfg = $self->{app}->{api}->{map}->{method}->{$method_id};
+    my $method_cfg = $self->{api}->{_method}->{$method_id};
 
     # method wasn't found
-    if ( !$method_cfg ) {
-        return res [ 404, qq[Method "$method_id" was not found] ];
-    }
+    return res [ 404, qq[Method "$method_id" was not found] ] if !$method_cfg;
 
     # method was found
-    else {
+    my $method_permissions = $method_cfg->{permissions};
 
-        # user is root, method authentication is not required
-        if ( $self->{is_root} ) {
-            return res 200;
-        }
+    # method has no permissions, authorization is not required
+    return res 200 if !$method_permissions;
 
-        # method has no permissions, authorization is not required
-        elsif ( !$method_cfg->{permissions} ) {
-            return res 200;
-        }
+    if ( is_plain_arrayref $method_permissions) {
 
-        # auth has no permisisons, api call is forbidden
-        elsif ( !$self->{permissions} ) {
-            return res [ 403, qq[Insufficient permissions for method "$method_id"] ];
-        }
+        # compare permissions for authenticated session only
+        if ( $self->{is_authenticated} ) {
+            my $auth_permissions = $self->{permissions};
 
-        # compare permissions
-        else {
-            for my $role_name ( $method_cfg->{permissions}->@* ) {
-                if ( exists $self->{permissions}->{$role_name} ) {
-                    return res 200;
-                }
+            # compare permissions
+            for my $permission ( $method_permissions->@* ) {
+                return res 200 if $auth_permissions->{$permission};
             }
-
-            return res [ 403, qq[Insufficient permissions for method "$method_id"] ];
         }
     }
+    else {
+        return res 200 if $method_permissions eq $PERMISSION_ANY_AUTHENTICATED_USER && $self->{is_authenticated};
+    }
+
+    return res [ 403, qq[Insufficient permissions for method "$method_id"] ];
 }
 
 sub api_call ( $self, $method_id, @ ) {
@@ -120,12 +110,12 @@ sub api_call_arrayref ( $self, $method_id, $args, $cb = undef ) {
         return $can_call;
     }
     else {
-        my $map = $self->{app}->{api}->{map};
+        my $api = $self->{api};
 
         # get method
-        my $method_cfg = $map->{method}->{$method_id};
+        my $method_cfg = $api->{_method}->{$method_id};
 
-        my $obj = $map->{obj}->{ $method_cfg->{class_name} };
+        my $obj = $api->{_obj}->{ $method_cfg->{class_name} };
 
         my $method_name = $method_cfg->{local_method_name};
 
@@ -139,7 +129,7 @@ sub api_call_arrayref ( $self, $method_id, $args, $cb = undef ) {
                     auth => $self,
                     _cb  => $cv,
                   },
-                  'Pcore::App::API::Auth::Request';
+                  'Pcore::App::API::Request';
 
                 # call method
                 if ( !eval { $obj->$method_name( $req, $args ? $args->@* : () ); 1 } ) {
@@ -158,7 +148,7 @@ sub api_call_arrayref ( $self, $method_id, $args, $cb = undef ) {
                 auth => $self,
                 _cb  => $cb,
               },
-              'Pcore::App::API::Auth::Request';
+              'Pcore::App::API::Request';
 
             # call method
             if ( !eval { $obj->$method_name( $req, $args ? $args->@* : () ); 1 } ) {
